@@ -4,6 +4,7 @@ from gpt_index.indices.vector_store.base import GPTVectorStoreIndex
 from gpt_index.indices.vector_store.vector_indices import (
     GPTChromaIndex,
     GPTFaissIndex,
+    GPTOpensearchIndex,
     GPTPineconeIndex,
     GPTQdrantIndex,
     GPTSimpleVectorIndex,
@@ -18,4 +19,5 @@ __all__ = [
     "GPTWeaviateIndex",
     "GPTQdrantIndex",
     "GPTChromaIndex",
+    "GPTOpensearchIndex",
 ]
