@@ -7,7 +7,7 @@ from typing import Any, Generator, Optional, Tuple
 import openai
 from langchain import Cohere, LLMChain, OpenAI
 from langchain.llms import AI21
-from langchain.llms.base import BaseLLM
+from langchain.schema import BaseLanguageModel
 
 from gpt_index.constants import MAX_CHUNK_SIZE, NUM_OUTPUTS
 from gpt_index.prompts.base import Prompt
@@ -17,6 +17,8 @@ from gpt_index.utils import (
     retry_on_exceptions_with_backoff,
 )
 
+logger = logging.getLogger(__name__)
+
 
 @dataclass
 class LLMMetadata:
@@ -30,9 +32,9 @@ class LLMMetadata:
     num_output: int = NUM_OUTPUTS
 
 
-def _get_llm_metadata(llm: BaseLLM) -> LLMMetadata:
+def _get_llm_metadata(llm: BaseLanguageModel) -> LLMMetadata:
     """Get LLM metadata from llm."""
-    if not isinstance(llm, BaseLLM):
+    if not isinstance(llm, BaseLanguageModel):
         raise ValueError("llm must be an instance of langchain.llms.base.LLM")
     if isinstance(llm, OpenAI):
         return LLMMetadata(
@@ -73,7 +75,7 @@ class LLMPredictor:
     """
 
     def __init__(
-        self, llm: Optional[BaseLLM] = None, retry_on_throttling: bool = True
+        self, llm: Optional[BaseLanguageModel] = None, retry_on_throttling: bool = True
     ) -> None:
         """Initialize params."""
         self._llm = llm or OpenAI(temperature=0, model_name="text-davinci-003")
@@ -131,7 +133,7 @@ class LLMPredictor:
         """
         formatted_prompt = prompt.format(llm=self._llm, **prompt_args)
         llm_prediction = self._predict(prompt, **prompt_args)
-        logging.debug(llm_prediction)
+        logger.debug(llm_prediction)
 
         # We assume that the value of formatted_prompt is exactly the thing
         # eventually sent to OpenAI, or whatever LLM downstream
@@ -211,7 +213,7 @@ class LLMPredictor:
         """
         formatted_prompt = prompt.format(llm=self._llm, **prompt_args)
         llm_prediction = await self._apredict(prompt, **prompt_args)
-        logging.debug(llm_prediction)
+        logger.debug(llm_prediction)
 
         # We assume that the value of formatted_prompt is exactly the thing
         # eventually sent to OpenAI, or whatever LLM downstream
