@@ -32,5 +32,11 @@ class PromptType(str, Enum):
     # table context
     TABLE_CONTEXT = "table_context"
 
+    # KG extraction prompt
+    KNOWLEDGE_TRIPLET_EXTRACT = "knowledge_triplet_extract"
+
+    # Simple Input prompt
+    SIMPLE_INPUT = "simple_input"
+
     # custom (by default)
     CUSTOM = "custom"
